==> qmmp-0.12.4.tar.bz2: qmmp-0.12.4/src/plugins/Output/shout/translations/shout_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="gl_ES">
<context>
    <name>OutputShoutFactory</name>
    <message>
        <location filename="../outputshoutfactory.cpp" line="40"/>
        <source>Icecast Plugin</source>
        <translation>Plugin Icecast</translation>
    </message>
    <message>
        <location filename="../outputshoutfactory.cpp" line="65"/>
        <source>About Icecast Output Plugin</source>
        <translation>Acerca do plugin de saida Icecast</translation>
    </message>
    <message>
        <location filename="../outputshoutfactory.cpp" line="66"/>
        <source>Qmmp Icecast Output Plugin</source>
        <translation>Plugin de saida Qmmp Icecast</translation>
    </message>
    <message>
        <location filename="../outputshoutfactory.cpp" line="67"/>
        <source>Compiled against libshout-%1</source>
        <translation>Compilando con libshout-%1</translation>
    </message>
    <message>
        <location filename="../outputshoutfactory.cpp" line="68"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: LLya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Connection Settings</source>
        <translation>Preferencias de conexión</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="32"/>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Port:</source>
        <translation>Porto:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="56"/>
        <source>Mount point:</source>
        <translation>Punto de montaxe:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="66"/>
        <source>User:</source>
        <translation>Usuario:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Password:</source>
        <translation>Contrasinal:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="86"/>
        <source>Quality:</source>
        <translation>Calidade:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="106"/>
        <source>Sample rate:</source>
        <translation>Taxa de mostra:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="136"/>
        <source>Public</source>
        <translation>Público</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="143"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.2.orig.tar.bz2: qmmp-1.2.2/src/plugins/Output/shout/translations/shout_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="gl_ES">
<context>
    <name>OutputShoutFactory</name>
    <message>
        <location filename="../outputshoutfactory.cpp" line="40"/>
        <source>Icecast Plugin</source>
        <translation>Plugin Icecast</translation>
    </message>
    <message>
        <location filename="../outputshoutfactory.cpp" line="65"/>
        <source>About Icecast Output Plugin</source>
        <translation>Acerca do plugin de saida Icecast</translation>
    </message>
    <message>
        <location filename="../outputshoutfactory.cpp" line="66"/>
        <source>Qmmp Icecast Output Plugin</source>
        <translation>Plugin de saida Qmmp Icecast</translation>
    </message>
    <message>
        <location filename="../outputshoutfactory.cpp" line="67"/>
        <source>Compiled against libshout-%1</source>
        <translation>Compilando con libshout-%1</translation>
    </message>
    <message>
        <location filename="../outputshoutfactory.cpp" line="68"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Connection Settings</source>
        <translation>Preferencias de conexión</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="32"/>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Port:</source>
        <translation>Porto:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="56"/>
        <source>Mount point:</source>
        <translation>Punto de montaxe:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="66"/>
        <source>User:</source>
        <translation>Usuario:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Password:</source>
        <translation>Contrasinal:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="86"/>
        <source>Quality:</source>
        <translation>Calidade:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="106"/>
        <source>Sample rate:</source>
        <translation>Taxa de mostra:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="136"/>
        <source>Public</source>
        <translation>Público</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="143"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
</context>
</TS>
